use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Anwar
Brohman
CPAN
Chase
David
Etheridge
Fredric
Golden
Ivan
Karen
Kent
Kivanc
Mengué
Mohammad
Moore
Olaf
Olivier
Randy
Shawn
Sibley
Spelling
Stauner
Test
Thomas
Tubert
Whitener
Yazan
brian
capoeirab
dagolden
dolmen
ether
foy
github
itub
kentfredric
kivancyazan
lib
mohammad
olaf
preprocessing
randy
sartak
stopwords
trs
wordlist
